@@ -190,8 +190,8 @@ void PipeWireRecordProduceThread::run()
 
 void PipeWireRecordProduceThread::deactivate()
 {
-    m_producer->m_deactivated = true;
     if (m_producer) {
+        m_producer->m_deactivated = true;
         m_producer->m_stream->setActive(false);
     }
 }
@@ -253,11 +253,14 @@ void PipeWireRecordProduce::setupStream()
         qCWarning(PIPEWIRERECORD_LOGGING) << "Could not allocate video codec context";
         return;
     }
-    m_avCodecContext->bit_rate = 100000000;
 
     const QSize size = m_stream->size();
     const Fraction framerate = m_stream->framerate();
 
+    // Have the bitrate depend on the size of the input stream. What looks acceptable on a small
+    // stream on a big one will look bad.
+    m_avCodecContext->bit_rate = size.width() * size.height() * 2;
+
     Q_ASSERT(!size.isEmpty());
     m_avCodecContext->width = size.width();
     m_avCodecContext->height = size.height();
@@ -274,7 +277,7 @@ void PipeWireRecordProduce::setupStream()
     av_dict_set_int(&options, "threads", 4, 0);
     av_dict_set(&options, "preset", "ultrafast", 0);
     av_dict_set(&options, "tune-content", "screen", 0);
-    av_dict_set(&options, "quality", "realtime", 0);
+    av_dict_set(&options, "deadline", "good", 0);
 
     int ret = avcodec_open2(m_avCodecContext, m_codec, &options);
     if (ret < 0) {
@@ -434,10 +437,10 @@ void PipeWireRecordProduce::render(const PipeWireFrame &frame)
         m_frame->m_avFrame->pts = AV_NOPTS_VALUE;
     }
 
-    // Let's add a key frame every 100 frames and also the first 5 frames
+    // Let's add a key frame every 100 frames and also the first frame
     if (frame.sequential && (*frame.sequential == 0 || (*frame.sequential - m_lastKeyFrame) > 100)) {
         m_frame->m_avFrame->key_frame = 1;
-        m_lastKeyFrame = frame.sequential.has_value() ? *frame.sequential : 11;
+        m_lastKeyFrame = *frame.sequential;
     }
 
     if (m_lastPts > 0 && m_frame->m_avFrame->pts <= m_lastPts) {
